# coding: utf-8

module AgileSolo
  class Consumer < Command
    attr_reader :name, :run_list, :data, :chef_repo

    def initialize(payload)
      @name = payload['name']
      @run_list = payload['run_list']
      @data = MultiJson.dump(payload['items'])
      @chef_repo = AgileSolo::Config.chef_repo

      Chef::Config[:data_bag_path] = File.join(@chef_repo, 'data_bags')
      chef_solo.config[:config_file] = File.join(@chef_repo, 'solo.rb')
      chef_solo.config[:override_runlist] = [@run_list]
    end

    def chef_solo
      @chef_solo ||= AgileSolo::Application::Solo.new
    end

    def execute
      begin
        update_data_bag
        chef_solo.run
      rescue => e
        puts e.backtrace.join("\n")
      end
    end

    def update_data_bag
      File.open(file_path, 'w') { |f| f.write(data) }
    end

  protected

    def file_path
      File.join(Chef::Config[:data_bag_path], name, 'items.json')
    end
  end
end
